@@ -1,9 +1,8 @@
-use pyo3::prelude::*;
-use pyo3::{wrap_pyfunction, PyObjectProtocol};
-
 use jmespath::{Rcvar, Variable};
 use pyo3::exceptions::PyValueError;
+use pyo3::prelude::*;
 use pyo3::types::{PyDict, PyList};
+use pyo3::PyObjectProtocol;
 
 /// A compiled JMESPath expression
 ///
